
ec2instance = dict()
ec2instances = list()

ec2instance = {"Monitoring":{"State":"disabled"},"PublicDnsName":"ec2-1-2-3-4.eu-west-1.compute.amazonaws.com","StateReason":{"Message":"","Code":""},"State":{"Code":16,"Name":"running"},"EbsOptimized":False,"LaunchTime":1502879688,"PublicIpAddress":"1.2.3.4","PrivateIpAddress":"192.168.1.2","ProductCodes":[],"VpcId":"vpc-123456a","StateTransitionReason":"","InstanceId":"i-1234567812345678","EnaSupport":True,"ImageId":"ami-12345678","PrivateDnsName":"ip-192-168-1-2.eu-west-1.compute.internal","KeyName":"id_private_key","SecurityGroups":[{"GroupName":"launch-wizard-30","GroupId":"sg-12345678"}],"Authorization":{"Type":"Profile","Value":"default"},"ClientToken":"lEXGY1502177192250","SubnetId":"subnet-12345678","InstanceType":"t2.xlarge","NetworkInterfaces":[{"Status":"in-use","MacAddress":"02:b8:d9:ff:6e:da","SourceDestCheck":True,"VpcId":"vpc-12345678","Description":"","NetworkInterfaceId":"eni-12345678","PrivateIpAddresses":[{"PrivateDnsName":"ip-192-168-1-2.eu-west-1.compute.internal","PrivateIpAddress":"192.168.1.2","Primary":True,"Association":{"PublicIp":"1.2.3.4","PublicDnsName":"ec2-1-2-3-4.eu-west-1.compute.amazonaws.com","IpOwnerId":"amazon"}}],"PrivateDnsName":"ip-192-168-1-2.eu-west-1.compute.internal","Attachment":{"Status":"attached","DeviceIndex":0,"DeleteOnTermination":True,"AttachmentId":"eni-attach-12345678","AttachTime":1502173593},"Groups":[{"GroupName":"launch-wizard-30","GroupId":"sg-12345678"}],"Ipv6Addresses":[],"OwnerId":"456404846277","PrivateIpAddress":"192.168.1.2","SubnetId":"subnet-12345678","Association":{"PublicIp":"1.2.3.4","PublicDnsName":"ec2-1-2-3-4.eu-west-1.compute.amazonaws.com","IpOwnerId":"amazon"}}],"SourceDestCheck":True,"Placement":{"Tenancy":"default","GroupName":"","AvailabilityZone":"eu-west-1b"},"Hypervisor":"xen","BlockDeviceMappings":[{"DeviceName":"/dev/sda1","Ebs":{"Status":"attached","DeleteOnTermination":True,"VolumeId":"vol-123456789123456789","AttachTime":1502173594}}],"Architecture":"x86_64","RootDeviceType":"ebs","RootDeviceName":"/dev/sda1","VirtualizationType":"hvm","Tags":[{"Value":"sec-es-pro-example","Key":"Name"}],"RegionName":"eu-west-1","AmiLaunchIndex":0}
ec2instances = [ec2instance]